==> cdktf-cdktf-provider-opentelekomcloud-0.0.85.tar.gz: package/lib/data-opentelekomcloud-obs-bucket.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataOpentelekomcloudObsBucketConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/obs_bucket.html#bucket DataOpentelekomcloudObsBucket#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketCorsRule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get allowedHeaders(): string[];
    /**
     * @stability stable
     */
    get allowedMethods(): string[];
    /**
     * @stability stable
     */
    get allowedOrigins(): string[];
    /**
     * @stability stable
     */
    get exposeHeaders(): string[];
    /**
     * @stability stable
     */
    get maxAgeSeconds(): number;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketEventNotificationsFilterRule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get value(): string;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketEventNotifications extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get events(): string[];
    /**
     * @stability stable
     */
    get filterRule(): any;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get topic(): string;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketLifecycleRuleExpiration extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get days(): number;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketLifecycleRuleNoncurrentVersionExpiration extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get days(): number;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketLifecycleRuleNoncurrentVersionTransition extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get days(): number;
    /**
     * @stability stable
     */
    get storageClass(): string;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketLifecycleRuleTransition extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get days(): number;
    /**
     * @stability stable
     */
    get storageClass(): string;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketLifecycleRule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enabled(): any;
    /**
     * @stability stable
     */
    get expiration(): any;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get noncurrentVersionExpiration(): any;
    /**
     * @stability stable
     */
    get noncurrentVersionTransition(): any;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    get transition(): any;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketLogging extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get targetBucket(): string;
    /**
     * @stability stable
     */
    get targetPrefix(): string;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketServerSideEncryption extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get algorithm(): string;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
}
/**
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucketWebsite extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get errorDocument(): string;
    /**
     * @stability stable
     */
    get indexDocument(): string;
    /**
     * @stability stable
     */
    get redirectAllRequestsTo(): string;
    /**
     * @stability stable
     */
    get routingRules(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/obs_bucket.html opentelekomcloud_obs_bucket}.
 *
 * @stability stable
 */
export declare class DataOpentelekomcloudObsBucket extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/obs_bucket.html opentelekomcloud_obs_bucket} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataOpentelekomcloudObsBucketConfig);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    /**
     * @stability stable
     */
    get bucketDomainName(): string;
    /**
     * @stability stable
     */
    corsRule(index: string): DataOpentelekomcloudObsBucketCorsRule;
    /**
     * @stability stable
     */
    eventNotifications(index: string): DataOpentelekomcloudObsBucketEventNotifications;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    lifecycleRule(index: string): DataOpentelekomcloudObsBucketLifecycleRule;
    /**
     * @stability stable
     */
    logging(index: string): DataOpentelekomcloudObsBucketLogging;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    serverSideEncryption(index: string): DataOpentelekomcloudObsBucketServerSideEncryption;
    /**
     * @stability stable
     */
    get storageClass(): string;
    /**
     * @stability stable
     */
    tags(key: string): string;
    /**
     * @stability stable
     */
    get versioning(): any;
    /**
     * @stability stable
     */
    website(index: string): DataOpentelekomcloudObsBucketWebsite;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-opentelekomcloud-0.3.20.tar.gz: package/lib/data-opentelekomcloud-obs-bucket.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataOpentelekomcloudObsBucketConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/obs_bucket#bucket DataOpentelekomcloudObsBucket#bucket}
    */
    readonly bucket: string;
}
export declare class DataOpentelekomcloudObsBucketCorsRule extends cdktf.ComplexComputedList {
    get allowedHeaders(): string[];
    get allowedMethods(): string[];
    get allowedOrigins(): string[];
    get exposeHeaders(): string[];
    get maxAgeSeconds(): number;
}
export declare class DataOpentelekomcloudObsBucketEventNotificationsFilterRule extends cdktf.ComplexComputedList {
    get name(): string;
    get value(): string;
}
export declare class DataOpentelekomcloudObsBucketEventNotifications extends cdktf.ComplexComputedList {
    get events(): string[];
    get filterRule(): cdktf.IResolvable;
    get id(): string;
    get topic(): string;
}
export declare class DataOpentelekomcloudObsBucketLifecycleRuleExpiration extends cdktf.ComplexComputedList {
    get days(): number;
}
export declare class DataOpentelekomcloudObsBucketLifecycleRuleNoncurrentVersionExpiration extends cdktf.ComplexComputedList {
    get days(): number;
}
export declare class DataOpentelekomcloudObsBucketLifecycleRuleNoncurrentVersionTransition extends cdktf.ComplexComputedList {
    get days(): number;
    get storageClass(): string;
}
export declare class DataOpentelekomcloudObsBucketLifecycleRuleTransition extends cdktf.ComplexComputedList {
    get days(): number;
    get storageClass(): string;
}
export declare class DataOpentelekomcloudObsBucketLifecycleRule extends cdktf.ComplexComputedList {
    get enabled(): cdktf.IResolvable;
    get expiration(): cdktf.IResolvable;
    get name(): string;
    get noncurrentVersionExpiration(): cdktf.IResolvable;
    get noncurrentVersionTransition(): cdktf.IResolvable;
    get prefix(): string;
    get transition(): cdktf.IResolvable;
}
export declare class DataOpentelekomcloudObsBucketLogging extends cdktf.ComplexComputedList {
    get targetBucket(): string;
    get targetPrefix(): string;
}
export declare class DataOpentelekomcloudObsBucketServerSideEncryption extends cdktf.ComplexComputedList {
    get algorithm(): string;
    get kmsKeyId(): string;
}
export declare class DataOpentelekomcloudObsBucketWebsite extends cdktf.ComplexComputedList {
    get errorDocument(): string;
    get indexDocument(): string;
    get redirectAllRequestsTo(): string;
    get routingRules(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/obs_bucket opentelekomcloud_obs_bucket}
*/
export declare class DataOpentelekomcloudObsBucket extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/opentelekomcloud/d/obs_bucket opentelekomcloud_obs_bucket} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataOpentelekomcloudObsBucketConfig
    */
    constructor(scope: Construct, id: string, config: DataOpentelekomcloudObsBucketConfig);
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    get bucketDomainName(): string;
    corsRule(index: string): DataOpentelekomcloudObsBucketCorsRule;
    eventNotifications(index: string): DataOpentelekomcloudObsBucketEventNotifications;
    get id(): string;
    lifecycleRule(index: string): DataOpentelekomcloudObsBucketLifecycleRule;
    logging(index: string): DataOpentelekomcloudObsBucketLogging;
    get region(): string;
    serverSideEncryption(index: string): DataOpentelekomcloudObsBucketServerSideEncryption;
    get storageClass(): string;
    tags(key: string): string | cdktf.IResolvable;
    get versioning(): cdktf.IResolvable;
    website(index: string): DataOpentelekomcloudObsBucketWebsite;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
